@@ -20,11 +20,11 @@ optimsimplex.xbar <- function(this=NULL,iexcl=NULL){
          call.=FALSE)
 
   # Vectorize by making the sum of all, substracting only one vector
-  cen <- apply(this$x[1:this$nbve,1:this$n],2,sum)
-  if (size(this$x[iexcl,1:this$n],1)==1){
+  cen <- apply(this$x[1:this$nbve,1:this$n,drop=FALSE],2,sum)
+  if (size(this$x[iexcl,1:this$n,drop=FALSE],1)==1){
     tmp <- matrix(this$x[iexcl,1:this$n],ncol=length(1:this$n))
   } else {
-    tmp <- this$x[iexcl,1:this$n]
+    tmp <- this$x[iexcl,1:this$n,drop=FALSE]
   }
   cen <- cen - apply(tmp,2,sum)
   nexcl <- size(iexcl,2)
